/*
Function Name:  range_acquire
Call Syntax: range_acquire(first_object, first_object)
Description:  Returns the distance in pixels between the calling object and the object named in parameter0.  
The range is as measured between the origin of the sprite, not the edge of the collision mask, as with the built-in distance_to_object(x,y,object) function.
This is potentially useful if you are interested in knowing the distance to the center of a sprite, rather than the edge of its collision mask.
Parameters: first_object (the index of the one of the objects to measure the range between), second_object (the index of the second object)
Returns: real number equal to the range in pixels between the calling object and the target object.  If either object does not exist, returns -1.
Results: none.
*/

{
  var first_object, second_object, a, b, c;
  first_object = argument0;
  second_object = argument1;
  
  if (instance_exists(first_object)) && (instance_exists(second_object))
  {
    //pythagorean theorm:  a^2 + b^2 = c^2
    //a = relative vertical distance between first and second
    //b = relative horizontal distance between first and second
    a = abs(first_object.y - second_object.y);
    b = abs(first_object.x - second_object.x);
    c = sqrt(sqr(a) + sqr(b));
    return c;
  }
  else return -1;
}
